km3modules.common.Dump
======================

.. currentmodule:: km3modules.common

.. autoclass:: Dump

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Dump.__init__
      ~Dump.add
      ~Dump.configure
      ~Dump.expose
      ~Dump.finish
      ~Dump.get
      ~Dump.pre_finish
      ~Dump.process
      ~Dump.require
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Dump.name
   
   